@@ -180,6 +180,10 @@ class Plotter:
         if isinstance(config['y_var'], str):
             config['y_var'] = [config['y_var']]
 
+        # Only keep the columns that are present in the data
+        config['x_var'] = config['x_var'] if config['x_var'] in data.columns else ''
+        config['y_var'] = [y for y in config['y_var'] if y in data.columns]
+        
         # Set the labels if not provided
         if not config.get('y_var_label', None):
             config['y_var_label'] = config['y_var']
@@ -195,10 +199,6 @@ class Plotter:
         plt.figure(figsize=Plotter._get_figure_size(
             config.get('aspect', 'wide')))
 
-        # Only keep the columns that are present in the data
-        config['x_var'] = config['x_var'] if config['x_var'] in data.columns else ''
-        config['y_var'] = [y for y in config['y_var'] if y in data.columns]
-
         if sum([(config[v] not in data.columns) for v in ['hue', 'style', 'size'] if config.get(v, None) is not None]) or \
                 len(config['x_var'])==0 or len(config['y_var'])==0:
             # print("Error: One or more of the hue, style, or size variables are not in the data.")
@@ -209,8 +209,8 @@ class Plotter:
         if config['x_var'] not in config['y_var']:
             data_m = data.melt(id_vars=[config['x_var']] + [config[k] for k in ['hue', 'style', 'size'] if config[k]],
                             value_vars=config['y_var'], var_name='variable', value_name='y_val')
-            data_m['variable'].replace(
-                config['y_var'], config['y_var_label'], inplace=True)
+            data_m['variable'] = data_m['variable'].replace(
+                config['y_var'], config['y_var_label'])
             sns.lineplot(data=data_m, x=config['x_var'], y='y_val', hue='variable', **{k: config[k] for k in [
                         'style', 'size'] if config[k]})
         else:
